/*
   This file is part of Massif Visualizer

   Copyright 2014 Milian Wolff <mail@milianw.de>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) version 3, or any
   later version accepted by the membership of KDE e.V. (or its
   successor approved by the membership of KDE e.V.), which shall
   act as a proxy defined in Section 6 of version 3 of the license.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef MASSIF_MODEL_ITEM_H
#define MASSIF_MODEL_ITEM_H

#include <QPair>
#include <QMetaType>

#include "treeleafitem.h"
#include "snapshotitem.h"

namespace Massif {

typedef QPair<const TreeLeafItem*, const SnapshotItem*> ModelItem;

}

Q_DECLARE_METATYPE(Massif::ModelItem)

#endif // MODEL_ITEM_H
